cloud_inquisitor\.plugins\.collectors
=====================================

Module contents
---------------

.. automodule:: cloud_inquisitor.plugins.collectors
    :members:
    :no-undoc-members:
    :show-inheritance:

Submodules
----------

.. toctree::
    :maxdepth: 1

    aws
